//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Canvas/ColorMapCanvas.cpp
//! @brief     Declares class ColorMapCanvas.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Canvas/ColorMapCanvas.h"
#include "GUI/Model/Data/Data2DItem.h"
#include "GUI/View/PlotScale/FontScalingEvent.h"
#include "GUI/View/Plotter/ColorMap.h"
#include "GUI/View/Plotter/PlotStatusLabel.h"
#include <QVBoxLayout>

ColorMapCanvas::ColorMapCanvas()
    : m_colorMap(new ColorMap)
    , m_canvasEvent(new FontScalingEvent(m_colorMap, this))
    , m_statusLabel(new PlotStatusLabel(m_colorMap, this))
{
    QObject::installEventFilter(m_canvasEvent);

    auto* layout = new QVBoxLayout(this);
    layout->setContentsMargins(0, 0, 0, 0);
    layout->setSpacing(0);

    layout->addWidget(m_colorMap);
    layout->addWidget(m_statusLabel);

    setStatusLabelEnabled(false);
}

void ColorMapCanvas::itemToCanvas(Data2DItem* item)
{
    m_colorMap->itemToMap(item);
}

void ColorMapCanvas::setStatusLabelEnabled(bool flag)
{
    m_statusLabel->setLabelEnabled(flag);
    m_statusLabel->setHidden(!flag);
}
