//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Canvas/IntensityDataCanvas.h
//! @brief     Defines class IntensityDataCanvas.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_CANVAS_INTENSITYDATACANVAS_H
#define BORNAGAIN_GUI_VIEW_CANVAS_INTENSITYDATACANVAS_H

#include "GUI/View/Access/DataAccessWidget.h"
#include <QAction>

class ColorMapCanvas;
class Data2DItem;

//! A color map that represents a Data2DItem, and provides standard actions
//! (reset view, save as) for external toolbars and context menus.

class IntensityDataCanvas : public DataAccessWidget {
public:
    explicit IntensityDataCanvas();

    void setJobOrDatafileItem(QObject* item) override;

    QSize sizeHint() const override;
    QSize minimumSizeHint() const override;

    QList<QAction*> actionList() override;

    void onResetViewAction();
    void onSavePlotAction();
    void onMousePress(QMouseEvent* event);

private:
    void initRotation();
    void rotateData();

    ColorMapCanvas* m_colorMapCanvas;
    QAction* m_resetViewAction;
    QAction* m_rotateDataAction;
    QAction* m_savePlotAction;
};

#endif // BORNAGAIN_GUI_VIEW_CANVAS_INTENSITYDATACANVAS_H
