//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Canvas/MaskEditorCanvas.h
//! @brief     Defines class MaskEditorCanvas.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_CANVAS_MASKEDITORCANVAS_H
#define BORNAGAIN_GUI_VIEW_CANVAS_MASKEDITORCANVAS_H

#include "GUI/View/Scene/MaskFlags.h"
#include <QItemSelectionModel>
#include <QModelIndex>
#include <QWidget>

class Data2DItem;
class MaskGraphicsScene;
class MaskGraphicsView;
class MaskResultsPresenter;
class PlotStatusLabel;

//! Painting widget for MaskEditor, contains graphics scene and graphics view

class MaskEditorCanvas : public QWidget {
    Q_OBJECT
public:
    MaskEditorCanvas(QWidget* parent = nullptr);

    void updateMaskCanvas(Data2DItem* data2DItem, QItemSelectionModel* selModel);

    void resetMaskCanvas();

    MaskGraphicsScene* getScene() { return m_scene; }

signals:
    void changeActivityRequest(MaskFlags::MaskMode);
    void deleteSelectedRequest();

public slots:
    void onPresentationChange(bool pixelized);
    void onSavePlotRequest();
    void onResetViewRequest();

private:
    void setZoomToROI();

    MaskGraphicsScene* m_scene;
    MaskGraphicsView* m_view;
    Data2DItem* m_data2DItem;
    PlotStatusLabel* m_statusLabel;
    MaskResultsPresenter* m_resultsPresenter;
};

#endif // BORNAGAIN_GUI_VIEW_CANVAS_MASKEDITORCANVAS_H
