//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Canvas/ProjectionsEditorCanvas.h
//! @brief     Defines class ProjectionsEditorCanvas.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_CANVAS_PROJECTIONSEDITORCANVAS_H
#define BORNAGAIN_GUI_VIEW_CANVAS_PROJECTIONSEDITORCANVAS_H

#include "GUI/View/Scene/MaskFlags.h"
#include <QWidget>
#include <memory>

class ColorMap;
class Data2DItem;
class LineItem;
class MaskGraphicsScene;
class MaskGraphicsView;
class OverlayItem;
class PlotStatusLabel;

//! Holds a graphics scene to draw projections on top of ColorMap. Being a part
//! of ProjectionEditor, provides interaction logic between graphics scene and ProjectionsWidget.

//! Particularly, it creates temporary ProjectionItem in projection container, when mouse
//! is inside ColorMap viewport.

class ProjectionsEditorCanvas : public QWidget {
    Q_OBJECT
public:
    ProjectionsEditorCanvas(QWidget* parent = nullptr);
    virtual ~ProjectionsEditorCanvas();

    void updateProjsCanvas(Data2DItem* data2DItem);
    void resetProjsCanvas();

signals:
    void changeProjectionsTabRequest(MaskFlags::MaskMode);
    void changeActivityRequest(MaskFlags::MaskMode);
    void deleteSelectedRequest();
    void marginsChanged(double left, double right);

public slots:
    void onEnteringColorMap();
    void onLeavingColorMap();
    void onPositionChanged(double x, double y);
    void onResetViewRequest();
    void onActivityChanged(MaskFlags::MaskMode mask_mode);

private:
    void onLineItemMoved(OverlayItem* sender);
    void setColorMap(ColorMap* colorMap);
    void setConnected(bool isConnected);

    MaskGraphicsScene* m_scene;
    MaskGraphicsView* m_view;
    ColorMap* m_colorMap;
    PlotStatusLabel* m_statusLabel;

    std::unique_ptr<LineItem> m_liveProjection; //!< temporary, matching mouse move
    Data2DItem* m_data2DItem;

    MaskFlags::MaskMode m_currentActivity;
    bool m_block_update = false;
};

#endif // BORNAGAIN_GUI_VIEW_CANVAS_PROJECTIONSEDITORCANVAS_H
