//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Instrument/InstrumentLibraryEditor.h
//! @brief     Defines class InstrumentLibraryEditor.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_INSTRUMENT_INSTRUMENTLIBRARYEDITOR_H
#define BORNAGAIN_GUI_VIEW_INSTRUMENT_INSTRUMENTLIBRARYEDITOR_H

#include "GUI/View/Instrument/InstrumentsTreeModel.h"
#include "GUI/View/Widget/GroupBoxes.h"
#include <QDialog>
#include <QDialogButtonBox>
#include <QScrollArea>
#include <QTreeView>

class InstrumentItem;
class InstrumentLibrary;

class InstrumentLibraryEditor : public QDialog {
    Q_OBJECT
public:
    InstrumentLibraryEditor(QWidget* parent, InstrumentLibrary* instrumentLibrary);
    ~InstrumentLibraryEditor() override;

    //! Execute the dialog for choosing an instrument from the library.
    //! Returns nullptr if canceled
    InstrumentItem* execChoose();

    //! Execute the dialog to add an instrument to the library.
    void execAdd(const InstrumentItem& instrumentToAdd);

private:
    void onItemDoubleClickedForChoose(const QModelIndex& index);
    void onCurrentChangedForChoose();
    QList<QAction*> getOverlayActions(const QModelIndex& index, bool asHover);
    void createWidgetsForCurrentInstrument();

    void onInstrumentNameEdited(const QString& newName);
    void onInstrumentDescriptionEdited(const QString& t);
    void onInstrumentChangedByEditor();

    void applySplitterPos();
    void saveSplitterPos();

    InstrumentLibrary* m_instrumentLibrary;
    InstrumentsTreeModel* m_treeModel;
    InstrumentItem* m_chosenItem;

    QTreeView* m_treeView;
    QScrollArea* m_scrollArea;
    QDialogButtonBox* m_buttonBox;
};

#endif // BORNAGAIN_GUI_VIEW_INSTRUMENT_INSTRUMENTLIBRARYEDITOR_H
