//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Tuning/JobRealTimeWidget.cpp
//! @brief     Implements class JobRealTimeWidget.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Tuning/JobRealTimeWidget.h"
#include "GUI/Model/Job/JobItem.h"
#include "GUI/Model/Model/JobModel.h"
#include "GUI/View/Tool/mainwindow_constants.h"
#include "GUI/View/Tuning/ParameterTuningStackPresenter.h"
#include "GUI/View/Tuning/ParameterTuningWidget.h"
#include <QSettings>
#include <QVBoxLayout>

JobRealTimeWidget::JobRealTimeWidget(JobModel* jobModel, QWidget* parent)
    : QWidget(parent)
    , m_stackedWidget(new ParameterTuningStackPresenter())
    , m_jobModel(jobModel)
{
    setWindowTitle(GUI::Style::JobRealTimeWidgetName);
    setObjectName("JobRealTimeWidget");
    setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);

    auto* mainLayout = new QVBoxLayout(this);
    mainLayout->setContentsMargins(0, 0, 0, 0);
    mainLayout->setSpacing(0);
    mainLayout->addWidget(m_stackedWidget);

    setFixedWidth(GUI::Style::FIT_ACTIVITY_PANEL_WIDTH);
    applySettings();
}

void JobRealTimeWidget::resizeEvent(QResizeEvent* event)
{
    QWidget::resizeEvent(event);
    emit widthChanged(width());
    setMinimumWidth(0);
    setMaximumWidth(QWIDGETSIZE_MAX);
}

ParameterTuningWidget* JobRealTimeWidget::parameterTuningWidget(JobItem* jobItem)
{
    return m_stackedWidget->itemWidget(jobItem);
}

void JobRealTimeWidget::setJobItem(JobItem* jobItem)
{
    if (!isValidJobItem(jobItem)) {
        m_stackedWidget->hideWidgets();
        return;
    }
    m_stackedWidget->setItem(jobItem, m_jobModel);
}

//! Returns true if JobItem is valid for real time simulation.

bool JobRealTimeWidget::isValidJobItem(JobItem* item)
{
    return item && (item->isCompleted() || item->isCanceled() || item->isFailed());
}

void JobRealTimeWidget::applySettings()
{
    QSettings settings;
    if (settings.childGroups().contains(GUI::Style::S_FIT_ACTIVITY_PANEL)) {
        settings.beginGroup(GUI::Style::S_FIT_ACTIVITY_PANEL);
        setFixedWidth(settings.value(GUI::Style::S_FIT_ACTIVITY_PANEL_SIZE).toSize().width());
        settings.endGroup();
    }
}
